@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: tls
-version: 1.3.4
-id: tls-1.3.4-c1ffd726a31a364e53d7dbf7360c4f21
-key: tls_Fw43CpZSfHUFGOtrNagnxE
+version: 1.3.5
+id: tls-1.3.5-cc53341e73a1ad5e4154c36129b6c569
+key: tls_3mTEcV7rEGs5MTZIHCbEDm
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: Vincent Hanquez <vincent@snarc.org>
@@ -48,26 +48,26 @@ hidden-modules: Network.TLS.Cap Network.TLS.Struct Network.TLS.Core
                 Network.TLS.Util.Serialization Network.TLS.Types Network.TLS.Wire
                 Network.TLS.X509
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/tls-1.3.4
-library-dirs: /usr/lib/ghc-7.10.3/site-local/tls-1.3.4
-data-dir: /usr/share/arm-linux-ghc-7.10.3/tls-1.3.4
-hs-libraries: HStls-1.3.4-Fw43CpZSfHUFGOtrNagnxE
+import-dirs: /usr/lib/ghc-7.10.3/site-local/tls-1.3.5
+library-dirs: /usr/lib/ghc-7.10.3/site-local/tls-1.3.5
+data-dir: /usr/share/arm-linux-ghc-7.10.3/tls-1.3.5
+hs-libraries: HStls-1.3.5-3mTEcV7rEGs5MTZIHCbEDm
 depends:
-    asn1-encoding-0.9.3-973a6b8f38afc857f3a60ad311c8ee45
-    asn1-types-0.3.2-3969820adc8283f126affe054010f830
+    asn1-encoding-0.9.3-fec344bb54bb5da4bfe7deb0a3562b73
+    asn1-types-0.3.2-0a9b49f98bdd53624b82b3c86ed41efa
     async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
-    cryptonite-0.13-349d06636b05d6ecd7f57ca79abfe077
+    cryptonite-0.15-52f487cbd51518538a9e7cbc4eddf82b
     data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
-    memory-0.11-3a745e41fe78387f608c420e9b455d25
+    memory-0.12-092368f288b8a5ed89de3a4f849c43f2
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    x509-1.6.3-9c5cbae50b7250847fc648c7f7d122e6
-    x509-store-1.6.1-741461c55f7edc5697c99a37f0436ee6
-    x509-validation-1.6.3-47849fe369535aae4a3b7e2d99568d36
+    x509-1.6.3-ea92228b2bfea35f7dd001d2924d4ebd
+    x509-store-1.6.1-43851738bccd019b67ff937f268f43a7
+    x509-validation-1.6.3-2eb8745653ed8864def666b7c1efed9d
 haddock-interfaces: /usr/share/doc/haskell-tls/html/tls.haddock
 haddock-html: /usr/share/doc/haskell-tls/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
